@@ -6,7 +6,7 @@ Mojolicious::Plugin::Riotjs - A Mojolicious  plugin for including riot.js .tag f
 
 =head1 VERSION
 
-0.0203
+0.03
 
 =head1 DESCRIPTION
 
@@ -37,7 +37,7 @@ L<npm|https://www.npmjs.com/>:
   app->plugin("riotjs");
   app->asset(
     "app.js" => qw(
-      https://muut.com/riotjs/dist/demo/js/riot.js
+      http://cdnjs.cloudflare.com/ajax/libs/riot/2.0.13/riot.js
       /js/todo.tag
       /js/main.js
     )
@@ -90,7 +90,7 @@ L<npm|https://www.npmjs.com/>:
 use Mojo::Base 'Mojolicious::Plugin';
 use Cwd ();
 
-our $VERSION = '0.0203';
+our $VERSION = '0.03';
 
 $ENV{NODE_PATH} ||= '';
 
@@ -111,11 +111,9 @@ C<NODE_PATH> if already set.
 
 sub node_paths {
   my ($self, $app) = @_;
-  my $node_modules = Cwd::abs_path('node_modules');
   my %PATH;
 
-  return grep { -d and !$PATH{$_}++ } split(/:/, $ENV{NODE_PATH}), $node_modules,
-    $app->home->rel_dir('node_modules');
+  grep { $_ and -d and !$PATH{$_}++ } split(/:/, $ENV{NODE_PATH}), eval { Cwd::abs_path('node_modules') }, $app->home->rel_dir('node_modules');
 }
 
 =head2 register
